@@ -15,5 +15,10 @@ class RunFastSpider(object):
 	@classmethod
 	def run(cls, spider_path, thread_count):
 		module, class_name = spider_path.rsplit(".", 1)
-		spider_cls = importlib.import_module(module).__getattribute__(class_name)
-		spider_cls(thread_count).start()
+		mod = importlib.import_module(module)
+		try:
+			obj = getattr(mod, class_name)
+		except AttributeError:
+			raise NameError(f"Module '{module}' doesn't define any object named '{class_name}'")
+
+		obj(thread_count).start()
