@@ -9,7 +9,6 @@ Desc: 配置文件
 """
 
 # 爬虫配置
-import os
 
 SPIDER_THREAD_COUNT = 1  # 爬虫并发数
 
@@ -68,6 +67,16 @@ LOGGER = dict(
 	# LOG_ENCODING="utf8",  # 日志文件编码
 )
 
+# 【必填项】 REDIS
+REDISDB_URL = ""
+REDISDB_IP = "127.0.0.1"
+REDISDB_PORT = 6379
+REDISDB_USER_PASS = ""
+# 默认 0 到 15 共16个数据库
+REDISDB_DB = 1
+# 心跳检测的数据缓存的时间，以秒为单位
+REDISDB_TIME = 5
+
 # 导入自定义settings的配置文件
 try:
 	from settings import *
